>From c3d84af1e702e5b1788eae4f2a431c01d17482ac Mon Sep 17 00:00:00 2001
From: Roiy <roiy@cs.umanitoba.ca>
Date: Fri, 4 Oct 2013 14:03:55 -0500
Subject: [PATCH 9/9] MED interface additions

---
 include/vlc_interface.h                          |   1 +
 modules/gui/qt4/components/controller_widget.cpp |  38 ++++++
 modules/gui/qt4/components/controller_widget.hpp |  27 ++++
 modules/gui/qt4/components/interface_widgets.cpp | 150 +++++++++++++++++++++++
 modules/gui/qt4/components/interface_widgets.hpp |  25 +++-
 modules/gui/qt4/dialogs/annotations.cpp          |  83 +++++++++++++
 modules/gui/qt4/dialogs/annotations.hpp          |  51 ++++++++
 modules/gui/qt4/input_manager.cpp                | 102 ++++++++++++++-
 modules/gui/qt4/input_manager.hpp                |  21 +++-
 9 files changed, 492 insertions(+), 6 deletions(-)
 create mode 100644 modules/gui/qt4/dialogs/annotations.cpp
 create mode 100644 modules/gui/qt4/dialogs/annotations.hpp

diff --git a/include/vlc_interface.h b/include/vlc_interface.h
index 485c303..a94a7c6 100644
--- a/include/vlc_interface.h
+++ b/include/vlc_interface.h
@@ -158,6 +158,7 @@ typedef enum vlc_dialog {
     INTF_DIALOG_PREFS,
     INTF_DIALOG_BOOKMARKS,
     INTF_DIALOG_EXTENDED,
+    INTF_DIALOG_ANNOTATIONS,
 
     INTF_DIALOG_POPUPMENU = 20,
     INTF_DIALOG_AUDIOPOPUPMENU,
diff --git a/modules/gui/qt4/components/controller_widget.cpp b/modules/gui/qt4/components/controller_widget.cpp
index aad30a2..a15f4b8 100644
--- a/modules/gui/qt4/components/controller_widget.cpp
+++ b/modules/gui/qt4/components/controller_widget.cpp
@@ -30,6 +30,7 @@
 
 #include "input_manager.hpp"         /* Get notification of Volume Change */
 #include "util/input_slider.hpp"     /* SoundSlider */
+#include "components/events_layers_widget.hpp"
 
 #include <math.h>
 
@@ -254,6 +255,11 @@ void AtoB_Button::updateButtonIcons( bool timeA, bool timeB )
     }
 }
 
+void AutoJumpButton::updateButtonIcons( bool b_jump )
+{
+    setIcon( b_jump ? QIcon( ":/toolbar/skip_fw" ) : QIcon( ":/toolbar/no_auto_jump" ) );
+}
+
 void LoopButton::updateButtonIcons( int value )
 {
     setChecked( value != NORMAL );
@@ -261,6 +267,38 @@ void LoopButton::updateButtonIcons( int value )
                                      : QIcon( ":/buttons/playlist/repeat_all" ) );
 }
 
+void AddRemLayerButton::toggleAddRemoveLayer()
+{
+    input_thread_t *p_input = playlist_CurrentInput( THEPL );
+    if ( !p_input )
+        return;
+
+    bAdded = !bAdded;
+    if ( bAdded )
+    {
+        input_Control( p_input, INPUT_SELECT_LAYER , iLayerId);
+
+        EventsLayersWidget *widget = (EventsLayersWidget*)parent();
+        widget->addLayerStyle( iLayerId );
+    }
+    else
+    {
+        input_Control( p_input, INPUT_DESELECT_LAYER , iLayerId);
+
+        EventsLayersWidget *widget = (EventsLayersWidget*)parent();
+        widget->removeLayerStyle( iLayerId );
+    }
+
+    THEMIM->getIM()->updateMetaSlider();
+    vlc_object_release( p_input );
+}
+
+void AddRemLayerButton::extAddRemoveLayer( bool bAddCmd )
+{
+    if ( bAddCmd != bAdded )
+        toggleAddRemoveLayer();
+}
+
 void AspectRatioComboBox::updateRatios()
 {
     /* Clear the list before updating */
diff --git a/modules/gui/qt4/components/controller_widget.hpp b/modules/gui/qt4/components/controller_widget.hpp
index 48a6d96..bdba79b 100644
--- a/modules/gui/qt4/components/controller_widget.hpp
+++ b/modules/gui/qt4/components/controller_widget.hpp
@@ -34,6 +34,7 @@
 
 #include <QWidget>
 #include <QToolButton>
+#include <QPushButton>
 #include <QComboBox>
 
 class QLabel;
@@ -70,6 +71,32 @@ private slots:
     void updateButtonIcons( bool, bool );
 };
 
+class AutoJumpButton : public QToolButton
+{
+    Q_OBJECT
+private slots:
+    void updateButtonIcons( bool );
+};
+
+class AddRemLayerButton : public QPushButton
+{
+    Q_OBJECT
+public:
+    AddRemLayerButton( QWidget *_parent, intf_thread_t * _p_intf ): QPushButton( _parent ), p_intf ( _p_intf )
+    {
+        CONNECT( this, clicked( ),
+                 this, toggleAddRemoveLayer( ) );
+    }
+    int iLayerId;
+    bool bAdded;
+    void extAddRemoveLayer( bool bAddCmd );
+private slots:
+    void toggleAddRemoveLayer( );
+
+private:
+    intf_thread_t* p_intf;
+};
+
 class AspectRatioComboBox : public QComboBox
 {
     Q_OBJECT
diff --git a/modules/gui/qt4/components/interface_widgets.cpp b/modules/gui/qt4/components/interface_widgets.cpp
index e25be11..b0cea64 100644
--- a/modules/gui/qt4/components/interface_widgets.cpp
+++ b/modules/gui/qt4/components/interface_widgets.cpp
@@ -900,3 +900,153 @@ void TimeLabel::paintEvent( QPaintEvent* event )
     }
     QLabel::paintEvent( event );
 }
+
+SegmentsTimeLabel::SegmentsTimeLabel( intf_thread_t *_p_intf, TimeLabel::Display _displayType )
+    : TimeLabel( _p_intf, _displayType  )
+{
+    switch( _displayType ) 
+    {
+        case TimeLabel::Elapsed:
+            setText( " --:-- " );
+            setToolTip( qtr("Elapsed segments time") );
+            break;
+        case TimeLabel::Remaining:
+            setText( " --:-- " );
+            setToolTip( qtr("Total/Remaining segments time")
+                        + QString("\n-")
+                        + qtr("Click to toggle between total and remaining time")
+                      );
+            break;
+        case TimeLabel::Both:
+            setText( " --:--/--:-- " );
+            setToolTip( QString( "- " )
+                + qtr( "Click to toggle between elapsed and remaining segments time" )
+                + QString( "\n- " )
+                + qtr( "Double click to jump to a chosen time position" ) );
+            break;
+    }
+    setAlignment( Qt::AlignRight | Qt::AlignVCenter );
+
+    cachedSegLength = 0;
+    psz_layerName = NULL;
+}
+
+void SegmentsTimeLabel::setDisplayPosition( float pos, int64_t t, int length )
+{
+    showBuffering = false;
+    bufTimer->stop();
+
+    input_thread_t *p_input = playlist_CurrentInput( THEPL );
+
+    if( ( pos == -1.f ) || ( !p_input ) )
+    {
+        setMinimumSize( QSize( 0, 0 ) );
+        if( displayType == TimeLabel::Both )
+            setText( "--:--/--:--" );
+        else
+            setText( "--:--" );
+
+        cachedSegLength = 0;
+        return;
+    }
+
+    int64_t totalTime;
+
+    if ( ( displayType == TimeLabel::Elapsed ) || ( displayType == TimeLabel::Both ) )
+        if ( input_Control( p_input, INPUT_GET_ANNOTATIONS_TIME, psz_layerName, t, &totalTime )
+            != VLC_SUCCESS )
+        {
+            vlc_object_release( p_input );
+            return;
+        }
+
+    if ( ( displayType == TimeLabel::Remaining ) || ( displayType == TimeLabel::Both ) )
+        if ( cachedSegLength == 0 )    //Need to get total segments length
+        {
+            if ( input_Control( p_input, INPUT_GET_ANNOTATIONS_TIME, psz_layerName, (int64_t)-1, &totalTime )
+                != VLC_SUCCESS )
+            {
+                vlc_object_release( p_input );
+                return;
+            }
+
+            cachedSegLength = totalTime / 1000000;
+        }
+    
+    vlc_object_release( p_input ); 
+
+    int time = totalTime / 1000000;
+
+    secstotimestr( psz_length, cachedSegLength );
+    secstotimestr( psz_time, ( b_remainingTime && cachedSegLength ) ? cachedSegLength - time
+                                                           : time );
+
+    // compute the minimum size that will be required for the psz_length
+    // and use it to enforce a minimal size to avoid "dancing" widgets
+    QSize minsize( 0, 0 );
+    if ( cachedSegLength > 0 )
+    {
+        QMargins margins = contentsMargins();
+        minsize += QSize(
+                  fontMetrics().size( 0, QString( psz_length ), 0, 0 ).width(),
+                  sizeHint().height()
+                );
+        minsize += QSize( margins.left() + margins.right() + 8, 0 ); /* +padding */
+
+        if ( b_remainingTime )
+            minsize += QSize( fontMetrics().size( 0, "-", 0, 0 ).width(), 0 );
+    }
+
+    switch( displayType )
+    {
+        case TimeLabel::Elapsed:
+            setMinimumSize( minsize );
+            setText( QString( psz_time ) );
+            break;
+        case TimeLabel::Remaining:
+            if( b_remainingTime )
+            {
+                setMinimumSize( minsize );
+                setText( QString("-") + QString( psz_time ) );
+            }
+            else
+            {
+                setMinimumSize( QSize( 0, 0 ) );
+                setText( QString( psz_length ) );
+            }
+            break;
+        case TimeLabel::Both:
+        default:
+            QString timestr = QString( "%1%2/%3" )
+            .arg( QString( (b_remainingTime && cachedSegLength) ? "-" : "" ) )
+            .arg( QString( psz_time ) )
+            .arg( QString( ( !cachedSegLength && time ) ? "--:--" : psz_length ) );
+
+            setText( timestr );
+            break;
+    }
+}
+
+void SegmentsTimeLabel::setDisplayPosition( float pos )
+{
+    if( pos == -1.f || cachedLength == 0)
+    {
+        setText( " --:--/--:-- " );
+        cachedSegLength = 0;
+        return;
+    }
+
+    int64_t time = pos * cachedLength * 1000000;
+
+    setDisplayPosition( pos, time, cachedLength);
+}
+
+void SegmentsTimeLabel::clearCache( )
+{
+    cachedSegLength = 0;
+}
+
+SegmentsTimeLabel::~SegmentsTimeLabel()
+{
+    free ( psz_layerName );
+}
diff --git a/modules/gui/qt4/components/interface_widgets.hpp b/modules/gui/qt4/components/interface_widgets.hpp
index d4be935..d4048a2 100644
--- a/modules/gui/qt4/components/interface_widgets.hpp
+++ b/modules/gui/qt4/components/interface_widgets.hpp
@@ -196,7 +196,7 @@ protected:
         toggleTimeDisplay();
         ClickableQLabel::mouseDoubleClickEvent( event );
     }
-private:
+protected:
     intf_thread_t *p_intf;
     bool b_remainingTime;
     int cachedLength;
@@ -211,13 +211,30 @@ private:
     char psz_time[MSTRTIME_MAX_SIZE];
     void toggleTimeDisplay();
     void paintEvent( QPaintEvent* );
-private slots:
-    void setDisplayPosition( float pos, int64_t time, int length );
-    void setDisplayPosition( float pos );
+protected slots:
+    virtual void setDisplayPosition( float pos, int64_t time, int length );
+    virtual void setDisplayPosition( float pos );
     void updateBuffering( float );
     void updateBuffering();
 };
 
+class SegmentsTimeLabel : public TimeLabel
+{
+    Q_OBJECT
+public:
+    SegmentsTimeLabel( intf_thread_t *_p_intf, TimeLabel::Display _displayType = TimeLabel::Both );
+    ~SegmentsTimeLabel();
+    char* psz_layerName;
+
+protected:
+    int cachedSegLength;
+
+protected slots:
+    void setDisplayPosition( float pos, int64_t time, int length );
+    void setDisplayPosition( float pos );
+    void clearCache();
+};
+
 class SpeedLabel : public QLabel
 {
     Q_OBJECT
diff --git a/modules/gui/qt4/dialogs/annotations.cpp b/modules/gui/qt4/dialogs/annotations.cpp
new file mode 100644
index 0000000..22a2f96
--- /dev/null
+++ b/modules/gui/qt4/dialogs/annotations.cpp
@@ -0,0 +1,83 @@
+/*****************************************************************************
+ * annotations.cpp : annotations display
+ ****************************************************************************
+ * Copyright (C) 2006-2008 the VideoLAN team
+ * $Id$
+ *
+ * Authors: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include "dialogs/annotations.hpp"
+
+#include "main_interface.hpp" /* Needed for external MI size */
+#include "input_manager.hpp"
+
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <vlc_modules.h>
+
+AnnotationsDialog::AnnotationsDialog( intf_thread_t *_p_intf )
+               : QVLCDialog( (QWidget*)_p_intf->p_sys->p_mi, _p_intf )
+{
+#ifdef __APPLE__
+    setWindowFlags( Qt::Drawer );
+#else
+    setWindowFlags( Qt::Tool );
+#endif
+
+    setWindowOpacity( var_InheritFloat( p_intf, "qt-opacity" ) );
+    setWindowTitle( qtr( "Media Annotations" ) );
+    setWindowRole( "vlc-annotations" );
+
+    QVBoxLayout *layout = new QVBoxLayout( this );
+    layout->setContentsMargins( 0, 0, 0, 0 );
+    layout->setSpacing( 1 );
+
+    annotationsWidget = new AnnotationsWidget( this , p_intf );
+    layout->addWidget( annotationsWidget );
+
+
+    QDialogButtonBox *closeButtonBox = new QDialogButtonBox( Qt::Horizontal, this );
+    closeButtonBox->addButton(
+        new QPushButton( qtr("&Close"), this ), QDialogButtonBox::RejectRole );
+    layout->addWidget( closeButtonBox );
+    CONNECT( closeButtonBox, rejected(), this, close() );
+
+    /* Restore geometry or move this dialog on the left pane of the MI */
+    if( !restoreGeometry( getSettings()->value("AnnotationsPanel/geometry").toByteArray() ) )
+    {
+        resize( QSize( 400, 100 ) );
+
+        MainInterface *p_mi = p_intf->p_sys->p_mi;
+        if( p_mi && p_mi->x() > 50 )
+            move( ( p_mi->x() - frameGeometry().width() - 10 ), p_mi->y() );
+        else
+            move ( 450 , 0 );
+    }
+
+    CONNECT( THEMIM->getIM(), positionUpdated( float, int64_t, int ),
+        annotationsWidget, update( ) );
+}
+
+AnnotationsDialog::~AnnotationsDialog()
+{
+    getSettings()->setValue("AnnotationsPanel/geometry", saveGeometry());
+}
+
diff --git a/modules/gui/qt4/dialogs/annotations.hpp b/modules/gui/qt4/dialogs/annotations.hpp
new file mode 100644
index 0000000..06f3f1f
--- /dev/null
+++ b/modules/gui/qt4/dialogs/annotations.hpp
@@ -0,0 +1,51 @@
+/*****************************************************************************
+ * annotations.hpp : Media Annotations
+ ****************************************************************************
+ * Copyright (C) 2006 the VideoLAN team
+ * $Id$
+ *
+ * Authors: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#ifndef QVLC_ANNOTATIONS_DIALOG_H_
+#define QVLC_ANNOTATIONS_DIALOG_H_ 1
+
+#include "components/annotations_widget.hpp"
+#include "util/qvlcframe.hpp"
+
+#include "util/singleton.hpp"
+
+class QTabWidget;
+class QTextEdit;
+
+class AnnotationsDialog : public QVLCDialog, public Singleton<AnnotationsDialog>
+{
+    Q_OBJECT
+private:
+    AnnotationsDialog( intf_thread_t * );
+    virtual ~AnnotationsDialog();
+
+    AnnotationsWidget *annotationsWidget;
+
+    QTextEdit *annotation_text;
+
+private slots:
+    friend class    Singleton<AnnotationsDialog>;
+};
+
+#endif
+
diff --git a/modules/gui/qt4/input_manager.cpp b/modules/gui/qt4/input_manager.cpp
index bd32de6..8e2a875 100644
--- a/modules/gui/qt4/input_manager.cpp
+++ b/modules/gui/qt4/input_manager.cpp
@@ -157,6 +157,7 @@ void InputManager::delInput()
     emit rateChanged( var_InheritFloat( p_intf, "rate" ) );
     emit nameChanged( "" );
     emit chapterChanged( 0 );
+    emit eventsChanged( 0 );
     emit titleChanged( 0 );
     emit playingStatusChanged( END_S );
 
@@ -226,6 +227,9 @@ void InputManager::customEvent( QEvent *event )
         UpdateNavigation();
         UpdateName(); /* Display the name of the Chapter, if exists */
         break;
+    case IMEvent::SeeksegmentsChanged:
+        emit eventsChanged( true );  //ROIY-correct?
+        break;
     case IMEvent::ItemRateChanged:
         UpdateRate();
         break;
@@ -318,6 +322,10 @@ static int InputEvent( vlc_object_t *p_this, const char *,
         event = new IMEvent( IMEvent::ItemTitleChanged );
         break;
 
+    case INPUT_EVENT_SEEKSEGMENTS:
+        event = new IMEvent( IMEvent::SeeksegmentsChanged );
+        break;
+
     case INPUT_EVENT_ES:
         event = new IMEvent( IMEvent::ItemEsChanged );
         break;
@@ -764,7 +772,10 @@ void InputManager::UpdateProgramEvent()
 void InputManager::sliderUpdate( float new_pos )
 {
     if( hasInput() )
+    {
+        msg_Err( p_input, "roiynav seek"); //ROIY REMOVE + the brackets
         var_SetFloat( p_input, "position", new_pos );
+    }
     emit seekRequested( new_pos );
 }
 
@@ -810,6 +821,52 @@ void InputManager::sectionMenu()
     }
 }
 
+void InputManager::toggleEditing()
+{
+    if( hasInput() )
+    {
+        emit eventEditToggled();
+    }
+}
+
+void InputManager::switchEditMode( bool bIsSegEndEdit, int64_t timeSwapped )
+{
+    if( hasInput() )
+    {
+        emit switchEdit( bIsSegEndEdit, timeSwapped );
+    }
+}
+
+void InputManager::setEventTimes( int64_t startTime, int64_t endTime )
+{
+    if( hasInput() )
+    {
+        emit updateEventTimes( startTime, endTime );
+    }
+}
+
+void InputManager::eventsModified()
+{
+    if( hasInput() )
+    {
+        emit eventsChanged( true );
+    }
+}
+
+int InputManager::saveEnhancementData()
+{
+    if( hasInput() )
+    {
+        //create data save window (save in existing or new file, dialogue)
+        return input_Control( p_input, INPUT_SAVE_ENHANCEMENT_FILE, NULL );
+
+            //ROIY move this to dialog
+
+    }
+
+    return VLC_EGENERIC;
+}
+
 /*
  *  Teletext Functions
  */
@@ -957,6 +1014,37 @@ void InputManager::AtoBLoop( float, int64_t i_time, int )
     }
 }
 
+/* Jump to previous event segment */
+void InputManager::prevSegment()
+{
+    if( hasInput() )
+    {
+        char psz_direction[5] = "prev";
+        if( input_Control( p_input, INPUT_JUMP_SEGMENT, &psz_direction ) != VLC_SUCCESS )
+            msg_Err( p_input, "Failed to jump to %s segment" , psz_direction );
+    }
+}
+
+
+void InputManager::nextSegment()
+{
+    if( hasInput() )
+    {
+        char psz_direction[5] = "next";
+        if( input_Control( p_input, INPUT_JUMP_SEGMENT, &psz_direction ) != VLC_SUCCESS )
+            msg_Err( p_input, "Failed to jump to %s segment" , psz_direction );
+    }
+}
+
+void InputManager::updateMetaSlider()
+{
+    emit layersChanged();
+
+    if( hasInput() )
+       if( input_Control( p_input, INPUT_DEMUX_SLAVE, "med" ) != VLC_SUCCESS )
+            msg_Err( p_input, "Failed to set med to demux" );
+}
+
 /**********************************************************************
  * MainInputManager implementation. Wrap an input manager and
  * take care of updating the main playlist input.
@@ -965,7 +1053,7 @@ void InputManager::AtoBLoop( float, int64_t i_time, int )
 
 MainInputManager::MainInputManager( intf_thread_t *_p_intf )
     : QObject(NULL), p_intf( _p_intf ),
-      random( VLC_OBJECT(THEPL), "random" ),
+      random( VLC_OBJECT(THEPL), "random" ), autoJump( VLC_OBJECT(THEPL), "autoJump" ),
       repeat( VLC_OBJECT(THEPL), "repeat" ), loop( VLC_OBJECT(THEPL), "loop" ),
       volume( VLC_OBJECT(THEPL), "volume" ), mute( VLC_OBJECT(THEPL), "mute" )
 {
@@ -980,6 +1068,7 @@ MainInputManager::MainInputManager( intf_thread_t *_p_intf )
     random.addCallback( this, SLOT(notifyRandom(bool)) );
     repeat.addCallback( this, SLOT(notifyRepeatLoop(bool)) );
     loop.addCallback( this, SLOT(notifyRepeatLoop(bool)) );
+    //autoJump.addCallback( this, SLOT(toggleAutoJump(bool)) );  ROIY - do i need this?
 
     volume.addCallback( this, SLOT(notifyVolume(float)) );
     mute.addCallback( this, SLOT(notifyMute(bool)) );
@@ -1121,6 +1210,17 @@ void MainInputManager::toggleRandom()
     config_PutInt( p_intf, "random", var_ToggleBool( THEPL, "random" ) );
 }
 
+void MainInputManager::toggleAutoJump()
+{
+    bool bAutoJump = var_ToggleBool( THEPL, "autoJump" );
+    if( p_input )
+        var_ToggleBool( p_input, "autoJump" );
+
+    //config_PutInt( p_intf, "autoJump", bAutoJump ); //ROIY - remove this, creates warning, check where else i added this
+
+    emit autoJumpChanged( bAutoJump );
+}
+
 void MainInputManager::notifyRandom(bool value)
 {
     emit randomChanged(value);
diff --git a/modules/gui/qt4/input_manager.hpp b/modules/gui/qt4/input_manager.hpp
index ff1a83d..b504a80 100644
--- a/modules/gui/qt4/input_manager.hpp
+++ b/modules/gui/qt4/input_manager.hpp
@@ -69,6 +69,7 @@ public:
         RandomChanged,
         LoopOrRepeatChanged,
         EPGEvent,
+        SeeksegmentsChanged,
     /*    SignalChanged, */
 
         FullscreenControlToggle = QEvent::User + IMEventTypeOffset + 20,
@@ -207,6 +208,16 @@ public slots:
     void activateTeletext( bool );     ///< Toggle buttons after click
     /* A to B Loop */
     void setAtoB();
+    /*  Segment Navigation */
+    void prevSegment(); //ROIY - decide name segment/event
+    void nextSegment();
+    void updateMetaSlider();
+    /* Segment Editing */
+    void toggleEditing();
+    void switchEditMode( bool bIsSegEndEdit, int64_t timeSwapped );
+    void setEventTimes( int64_t startTime, int64_t endTime );
+    void eventsModified();
+    int saveEnhancementData();
 
 private slots:
     void AtoBLoop( float, int64_t, int );
@@ -220,6 +231,7 @@ signals:
     /// Used to signal whether we should show navigation buttons
     void titleChanged( bool );
     void chapterChanged( bool );
+    void eventsChanged( bool );
     void inputCanSeek( bool );
     /// Statistics are updated
     void statisticsUpdated( input_item_t* );
@@ -248,6 +260,11 @@ signals:
     /// Program Event changes
     void encryptionChanged( bool );
     void epgChanged();
+    void layersChanged();
+    void eventEditToggled();
+    void switchEdit( bool, int64_t );
+    void updateEventTimes( int64_t, int64_t );
+
 };
 
 class MainInputManager : public QObject, public Singleton<MainInputManager>
@@ -284,7 +301,7 @@ private:
     InputManager            *im;
     input_thread_t          *p_input;
     intf_thread_t           *p_intf;
-    QVLCBool random, repeat, loop;
+    QVLCBool random, repeat, loop, autoJump;
     QVLCFloat volume;
     QVLCBool mute;
 
@@ -293,6 +310,7 @@ public slots:
     void play();
     void pause();
     void toggleRandom();
+    void toggleAutoJump();
     void stop();
     void next();
     void prev();
@@ -318,6 +336,7 @@ signals:
     void randomChanged( bool );
     void repeatLoopChanged( int );
     void leafBecameParent( int );
+    void autoJumpChanged( bool );
 };
 
 #endif
-- 
1.8.3.msysgit.0

